django_analyses.filters.output package — django_analyses 0.0.3 documentation

# django_analyses.filters.output package

## Submodules

## django_analyses.filters.output.output module

class `django_analyses.filters.output.output.` `OutputFilter`(data=None, queryset=None, *, request=None, prefix=None)

  Bases: `django_filters.rest_framework.filterset.FilterSet`

  Provides useful filtering options for the `Output` model.

  class `Meta`

    Bases: `object`

    `fields` = ('run',)
    `model`

      alias of `django_analyses.models.output.output.Output`

  `base_filters` = {'run': <django_filters.filters.ModelChoiceFilter object>}
  `declared_filters` = {}

## django_analyses.filters.output.output_definition module

class `django_analyses.filters.output.output_definition.` `OutputDefinitionFilter`(data=None, queryset=None, *, request=None, prefix=None)

  Bases: `django_filters.rest_framework.filterset.FilterSet`

  Provides useful filtering options for the `OutputDefinition` model.

  class `Meta`

    Bases: `object`

    `fields` = ('key', 'output_specification')
    `model`

      alias of `django_analyses.models.output.definitions.output_definition.OutputDefinition`

  `base_filters` = {'key': <django_filters.filters.CharFilter object>, 'output_specification': <django_filters.filters.AllValuesFilter object>}
  `declared_filters` = {'output_specification': <django_filters.filters.AllValuesFilter object>}

## Module contents